import { LarkAction, LarkEvent } from "./types"

/**
 * 是否为事件消息
 * @param body 事件消息体
 * @returns 是否为事件消息
 */
export const getIsEventMsg = (body: LarkEvent.Data) => {
  return body?.header?.event_type === "im.message.receive_v1"
}

/**
 * 获取事件文本类型
 * @param body 事件消息体
 * @returns 事件文本类型
 */
export const getMsgType = (body: LarkEvent.Data) => {
  return body?.event?.message?.message_type
}

/**
 * 获取对话流Id
 * @param body 事件消息体
 * @returns 对话流Id
 */
export const getChatId = (body: LarkEvent.Data) => {
  return body?.event?.message?.chat_id
}

/**
 * 获取用户Id
 * @param body 事件消息体
 * @returns 用户Id
 */
export const getUserId = (body: LarkEvent.Data) => {
  return body?.event?.sender?.sender_id?.user_id
}

/**
 * 是否为Action消息
 * @param body Action消息体
 * @returns 是否为Action消息
 */
export const getIsActionMsg = (body: LarkAction.Data) => {
  return !!body?.action
}

/**
 * 获取Action类型
 * @param body Action消息体
 * @returns Action类型
 */
export const getActionType = (body: LarkAction.Data) => {
  return body?.action?.tag
}

/**
 * 获取文本内容并剔除艾特信息
 * @param body 事件消息体
 * @returns 文本内容
 */
export const getMsgText = (body: LarkEvent.Data) => {
  try {
    const { text }: { text: string } = JSON.parse(body?.event?.message?.content)
    // 去掉@_user_1相关的内容，例如 '@_user_1 测试' -> '测试'
    const textWithoutAt = text.replace(/@_user_\d+/g, "")
    return textWithoutAt
  } catch {
    return ""
  }
}

/**
 * 获取聊天类型
 * @param body 事件消息体
 * @returns 聊天类型
 */
export const getChatType = (body: LarkEvent.Data) => {
  return body?.event?.message?.chat_type
}

/**
 * 获取艾特信息
 * @param body 事件消息体
 * @returns 艾特信息
 */
export const getMentions = (body: LarkEvent.Data) => {
  return body?.event?.message?.mentions
}

export { LarkAction, LarkEvent }
